Method: Arrow::Applet#actions
- Defined in:
- lib/arrow/applet.rb
#actions ⇒ Object (readonly)
The list of all valid actions on the applet
472 473 474 |
# File 'lib/arrow/applet.rb', line 472 def actions @actions end |
The list of all valid actions on the applet
472 473 474 |
# File 'lib/arrow/applet.rb', line 472 def actions @actions end |