Class: Arrow::Applet::SignatureStruct
- Inherits:
-
Struct
- Object
- Struct
- Arrow::Applet::SignatureStruct
- Defined in:
- lib/arrow/applet.rb
Overview
Applet signature struct. The fields are as follows: [name] The name of the applet; used for introspection and reports. [description] The description of the applet; used for introspection. [maintainer] The name of the maintainer for reports and introspection. [version] The version or revision number of the applet, which can be any object that has a #to_s method. [default_action] The action that will be run if no action is specified. [templates] A hash of templates used by the applet. The keys are Symbol identifiers which will be used for lookup, and the values are the paths to template files. [validator_profiles] A hash containing profiles for the built in form validator, one per action. See the documentation for FormValidator for the format of each profile hash.
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#default_action ⇒ Object
Returns the value of attribute default_action.
-
#description ⇒ Object
Returns the value of attribute description.
-
#maintainer ⇒ Object
Returns the value of attribute maintainer.
-
#name ⇒ Object
Returns the value of attribute name.
-
#templates ⇒ Object
Returns the value of attribute templates.
-
#validator_profiles ⇒ Object
Returns the value of attribute validator_profiles.
-
#version ⇒ Object
Returns the value of attribute version.
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def config @config end |
#default_action ⇒ Object
Returns the value of attribute default_action
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def default_action @default_action end |
#description ⇒ Object
Returns the value of attribute description
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def description @description end |
#maintainer ⇒ Object
Returns the value of attribute maintainer
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def maintainer @maintainer end |
#name ⇒ Object
Returns the value of attribute name
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def name @name end |
#templates ⇒ Object
Returns the value of attribute templates
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def templates @templates end |
#validator_profiles ⇒ Object
Returns the value of attribute validator_profiles
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def validator_profiles @validator_profiles end |
#version ⇒ Object
Returns the value of attribute version
93 94 95 |
# File 'lib/arrow/applet.rb', line 93 def version @version end |